@@ -47,6 +47,17 @@ from .RepositoryObjBaseClass import RepositoryObjBaseClass
 #MultiTenant OBject Store
 from .MultiTenantObjectStore import InvalidTenantNameException, MultiTenantObjectStore
 
+from .DoubleStringIndex import DoubleStringIndexClass, DoubleStringIndexInvalidKeyException
+
+from .DoubleStringIndex import ConnectionContext_Memory
+from .DoubleStringIndex import ConnectionContext_SimpleFileStore
+from .DoubleStringIndex import ConnectionContext_SQLAlchemy
+from .DoubleStringIndex import ConnectionContext_DynamoDB
+from .DoubleStringIndex import ConnectionContext_Migrating
+from .DoubleStringIndex import ConnectionContext_Caching
+from .DoubleStringIndex import ConnectionContext_TenantAware
+
+g
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
