@@ -11,8 +11,23 @@ class ObjectStore_Caching(ObjectStore):
   mainStore = None
   cullQueues = None
 
+  #For doubleStringIndex use same logic as memory store for the cache
+  # the cache won't expire
+  doubleStringIndexCache = None
+  #structure:
+  # {
+  #  objTypeSyt: {
+  #     byA: {},
+  #     byB: {}
+  #  }
+  # }
+  def _INT_getDictForDoubleStringIndexCache(self):
+    return self.doubleStringIndexCache
+
+
   def __init__(self, configJSON, externalFns, detailLogging, type, factoryFn):
     super(ObjectStore_Caching, self).__init__(externalFns, detailLogging, type)
+    self.doubleStringIndexCache = {}
 
     self.cullQueues = CullQueuesClass()
 
@@ -58,6 +73,5 @@ class ObjectStore_Caching(ObjectStore):
     return self.defaultPolicy
 
 
-
   def _getConnectionContext(self):
     return ConnectionContext(self)
\ No newline at end of file
