@@ -1,11 +1,12 @@
 from .objectStores_base import ObjectStore, ObjectStoreConnectionContext, StoringNoneObjectAfterUpdateOperationException, WrongObjectVersionException, TriedToDeleteMissingObjectException, TryingToCreateExistingObjectException, SuppliedObjectVersionWhenCreatingException
 from .paginatedResult import getPaginatedResult
 from .paginatedResultIterator import PaginatedResultIteratorBaseClass, sortListOfKeysToDictBySortString
+from object_store_abstraction.DoubleStringIndex import ConnectionContext_Memory
 
 class ConnectionContext(ObjectStoreConnectionContext):
   objectStore = None
   def __init__(self, objectStore):
-    super(ConnectionContext, self).__init__()
+    super(ConnectionContext, self).__init__(ConnectionContext_Memory(main_context=self))
     self.objectStore = objectStore
 
   #transactional memory not implemented
@@ -98,9 +99,20 @@ class ConnectionContext(ObjectStoreConnectionContext):
 # Class that will store objects in memory only
 class ObjectStore_Memory(ObjectStore):
   objectData = None
+
+  doubleStringIndex = None
+  #structure:
+  # {
+  #  objTypeSyt: {
+  #     byA: {},
+  #     byB: {}
+  #  }
+  # }
+
   def __init__(self, configJSON, externalFns, detailLogging, type, factoryFn):
     super(ObjectStore_Memory, self).__init__(externalFns, detailLogging, type)
     self.objectData = dict()
+    self.doubleStringIndex = {}
     #Dict = (objDICT, objectVersion, creationDate, lastUpdateDate)
 
   def _INT_getDictForObjectType(self, objectType):
@@ -109,6 +121,9 @@ class ObjectStore_Memory(ObjectStore):
       self.objectData[objectType] = dict()
     return self.objectData[objectType]
 
+  def _INT_getDictForDoubleStringIndex(self):
+    return self.doubleStringIndex
+
   def _getConnectionContext(self):
     return ConnectionContext(self)
 
